@@ -5,10 +5,10 @@ These Comparers are constructed by extracting data from the combination of obser
 
 Examples
 --------
->>> mr = ModelResult("Oresund2D.dfsu")
+>>> mr = ModelResult("Oresund2D.dfsu", item=0)
 >>> o1 = PointObservation("klagshamn.dfs0", item=0, x=366844, y=6154291, name="Klagshamn")
->>> mr.add_observation(o1, item=0)
->>> comparer = mr.extract()
+>>> con = Connector(o1, mr)
+>>> comparer = con.extract()
 """
 from collections.abc import Mapping, Iterable, Sequence
 from typing import List, Union
@@ -19,32 +19,13 @@ import pandas as pd
 import matplotlib.pyplot as plt
 from datetime import datetime, timedelta
 from copy import deepcopy
-from scipy.interpolate import interp1d
 
-from mikeio import Dfs0, Dataset
+from mikeio import Dataset
 import fmskill.metrics as mtr
-from fmskill.observation import Observation, PointObservation, TrackObservation
-from fmskill.plot import scatter, taylor_diagram, TaylorPoint
-from fmskill.skill import AggregatedSkill
-from fmskill.spatial import SpatialSkill
-
-
-def compare(mod, obs):
-    if not isinstance(obs, Observation):
-        obs = PointObservation(obs)
-    if isinstance(mod, str):
-        dfs = Dfs0(mod)
-        if len(dfs.items) > 1:
-            raise ValueError("Model ambiguous - please provide single item")
-        mod = dfs.read().to_dataframe()
-        mod.index = pd.DatetimeIndex(mod.index.round(freq="ms"), freq="infer")
-    elif isinstance(mod, pd.DataFrame):
-        if len(mod.columns) > 1:
-            raise ValueError("Model ambiguous - please provide single item")
-    elif isinstance(mod, pd.Series):
-        mod = mod.to_frame()
-    c = PointComparer(obs, mod)
-    return c
+from .observation import PointObservation, TrackObservation
+from .plot import scatter, taylor_diagram, TaylorPoint
+from .skill import AggregatedSkill
+from .spatial import SpatialSkill
 
 
 class BaseComparer:
@@ -385,7 +366,7 @@ class BaseComparer:
 
         Examples
         --------
-        >>> cc = mr.extract()
+        >>> cc = con.extract()
         >>> cc.skill().round(2)
                        n  bias  rmse  urmse   mae    cc    si    r2
         observation
@@ -569,7 +550,7 @@ class BaseComparer:
 
         Examples
         --------
-        >>> cc = mr.extract()  # with satellite track measurements
+        >>> cc = con.extract()  # with satellite track measurements
         >>> cc.spatial_skill(metrics='bias')
         <xarray.Dataset>
         Dimensions:      (x: 5, y: 5)
@@ -700,7 +681,7 @@ class BaseComparer:
 
         Examples
         --------
-        >>> cc = mr.extract()
+        >>> cc = con.extract()
         >>> dfsub = cc.sel_df(observation=['EPL','HKNA'])
         >>> dfsub = cc.sel_df(model=0)
         >>> dfsub = cc.sel_df(start='2017-10-1', end='2017-11-1')
@@ -1076,7 +1057,7 @@ class SingleObsComparer(BaseComparer):
 
         Examples
         --------
-        >>> cc = mr.extract()
+        >>> cc = con.extract()
         >>> cc['c2'].skill().round(2)
                        n  bias  rmse  urmse   mae    cc    si    r2
         observation
@@ -1147,7 +1128,7 @@ class SingleObsComparer(BaseComparer):
 
         Examples
         --------
-        >>> cc = mr.extract()
+        >>> cc = con.extract()
         >>> cc['c2'].score()
         0.3517964910888918
 
@@ -1214,7 +1195,7 @@ class SingleObsComparer(BaseComparer):
 
         Examples
         --------
-        >>> cc = mr.extract()
+        >>> cc = con.extract()
         >>> dfsub = cc['c2'].sel_df(model=0)
         >>> dfsub = cc['c2'].sel_df(start='2017-10-1', end='2017-11-1')
         >>> dfsub = cc['c2'].sel_df(area=[0.5,52.5,5,54])
@@ -1344,17 +1325,19 @@ class PointComparer(SingleObsComparer):
 
     Examples
     --------
-    >>> mr = ModelResult("Oresund2D.dfsu")
+    >>> mr = ModelResult("Oresund2D.dfsu", item=0)
     >>> o1 = PointObservation("klagshamn.dfs0", item=0, x=366844, y=6154291, name="Klagshamn")
-    >>> mr.add_observation(o1, item=0)
-    >>> comparer = mr.extract()
+    >>> con = Connector(o1, mr)
+    >>> comparer = con.extract()
     >>> comparer['Klagshamn']
     """
 
     def __init__(self, observation, modeldata):
         super().__init__(observation, modeldata)
         assert isinstance(observation, PointObservation)
-        self.observation.df = self.observation.df[self._mod_start : self._mod_end]
+        mod_start = self._mod_start - timedelta(seconds=1)  # avoid rounding err
+        mod_end = self._mod_end + timedelta(seconds=1)
+        self.observation.df = self.observation.df[mod_start:mod_end]
 
         if not isinstance(modeldata, list):
             modeldata = [modeldata]
@@ -1436,10 +1419,10 @@ class TrackComparer(SingleObsComparer):
 
     Examples
     --------
-    >>> mr = ModelResult("HKZN_local_2017.dfsu")
+    >>> mr = ModelResult("HKZN_local_2017.dfsu", item=2)
     >>> c2 = TrackObservation("Alti_c2_Dutch.dfs0", item=3, name="c2")
-    >>> mr.add_observation(c2, item=0)
-    >>> comparer = mr.extract()
+    >>> con = Connector(c2, mr)
+    >>> comparer = con.extract()
     >>> comparer['c2']
     """
 
@@ -1454,7 +1437,9 @@ class TrackComparer(SingleObsComparer):
     def __init__(self, observation, modeldata):
         super().__init__(observation, modeldata)
         assert isinstance(observation, TrackObservation)
-        self.observation.df = self.observation.df[self._mod_start : self._mod_end]
+        mod_start = self._mod_start - timedelta(seconds=1)  # avoid rounding err
+        mod_end = self._mod_end + timedelta(seconds=1)
+        self.observation.df = self.observation.df[mod_start:mod_end]
 
         if not isinstance(modeldata, list):
             modeldata = [modeldata]
@@ -1501,12 +1486,13 @@ class ComparerCollection(Mapping, Sequence, BaseComparer):
 
     Examples
     --------
-    >>> mr = ModelResult("Oresund2D.dfsu")
+    >>> mr = ModelResult("Oresund2D.dfsu", item=0)
     >>> o1 = PointObservation("klagshamn.dfs0", item=0, x=366844, y=6154291, name="Klagshamn")
     >>> o2 = PointObservation("drogden.dfs0", item=0, x=355568.0, y=6156863.0)
-    >>> mr.add_observation(o1, item=0)
-    >>> mr.add_observation(o2, item=0)
-    >>> comparer = mr.extract()
+    >>> con = Connector()
+    >>> con.add(o1, mr)
+    >>> con.add(o2, mr)
+    >>> comparer = con.extract()
 
     """
 
@@ -1717,7 +1703,7 @@ class ComparerCollection(Mapping, Sequence, BaseComparer):
 
         Examples
         --------
-        >>> cc = mr.extract()
+        >>> cc = con.extract()
         >>> cc.mean_skill().round(2)
                       n  bias  rmse  urmse   mae    cc    si    r2
         HKZN_local  564 -0.09  0.31   0.28  0.24  0.97  0.09  0.99
@@ -1872,7 +1858,7 @@ class ComparerCollection(Mapping, Sequence, BaseComparer):
 
         Examples
         --------
-        >>> cc = mr.extract()
+        >>> cc = con.extract()
         >>> cc.score()
         0.30681206
         >>> cc.score(weights=[0.1,0.1,0.8])
