@@ -1,8 +1,18 @@
 import warnings
 import numpy as np
 import pandas as pd
+from collections.abc import Iterable
 
 
+def is_iterable_not_str(obj):
+    """Check if an object is an iterable but not a string."""
+    if isinstance(obj, str):
+        return False
+    if isinstance(obj, Iterable):
+        return True
+    return False
+    
+
 def make_unique_index(df_index, offset_in_seconds=0.01, warn=True):
     """Given a non-unique DatetimeIndex, create a unique index by adding
     milliseconds to duplicate entries
@@ -39,4 +49,4 @@ def make_unique_index(df_index, offset_in_seconds=0.01, warn=True):
     # np.median(np.diff(df.index.values))/100
     offset_in_ns = offset_in_seconds * 1e9
     new_index = df_index + offset_in_ns * np.cumsum(values).astype(np.timedelta64)
-    return new_index
\ No newline at end of file
+    return new_index
