@@ -1,6 +1,7 @@
 import pytest
 import numpy as np
 from mikeio import Dfs0
+from datetime import datetime
 import fmskill
 
 
@@ -14,10 +15,12 @@ def fn_obs():
     return "tests/testdata/SW/eur_Hm0.dfs0"
 
 
-def test_compare(fn_mod, fn_obs):
+def test_compare(fn_obs, fn_mod):
     df_mod = Dfs0(fn_mod).read(items=0).to_dataframe()
-    c = fmskill.compare(df_mod, fn_obs)
+    c = fmskill.compare(fn_obs, df_mod)
     assert c.n_points == 67
+    assert c.start == datetime(2017, 10, 27, 0, 0, 0)
+    assert c.end == datetime(2017, 10, 29, 18, 0, 0)
 
 
 def test_compare_fn(fn_obs):
@@ -25,27 +28,29 @@ def test_compare_fn(fn_obs):
     assert c.n_points == 95
 
 
-def test_compare_df(fn_mod, fn_obs):
-    df_mod = Dfs0(fn_mod).read(items=0).to_dataframe()
+def test_compare_df(fn_obs, fn_mod):
     df_obs = Dfs0(fn_obs).read().to_dataframe()
-    c = fmskill.compare(df_mod, df_obs)
-    assert c.n_points == 67
-
-
-def test_compare_point_obs(fn_mod, fn_obs):
     df_mod = Dfs0(fn_mod).read(items=0).to_dataframe()
+    c = fmskill.compare(df_obs, df_mod)
+    assert c.n_points == 67
+    assert c.start == datetime(2017, 10, 27, 0, 0, 0)
+    assert c.end == datetime(2017, 10, 29, 18, 0, 0)
+
+
+def test_compare_point_obs(fn_obs, fn_mod):
     obs = fmskill.PointObservation(fn_obs, name="EPL")
-    c = fmskill.compare(df_mod, obs)
+    df_mod = Dfs0(fn_mod).read(items=0).to_dataframe()
+    c = fmskill.compare(obs, df_mod)
     assert c.n_points == 67
 
 
-def test_compare_fail(fn_mod, fn_obs):
+def test_compare_fail(fn_obs, fn_mod):
     df_mod = Dfs0(fn_mod).read(items=[0, 1, 2]).to_dataframe()
     with pytest.raises(ValueError):
         # multiple items in model df -> ambigous
-        c = fmskill.compare(df_mod, fn_obs)
+        fmskill.compare(fn_obs, df_mod)
 
     df_obs2, fn_mod2 = df_mod, fn_obs
     with pytest.raises(ValueError):
         # multiple items in obs df -> ambigous
-        c = fmskill.compare(fn_mod2, df_obs2)
+        fmskill.compare(df_obs2, fn_mod2)
